@@ -8,7 +8,8 @@ use indexmap::IndexMap;
 use crate::extensions::ResolveInfo;
 use crate::parser::types::Selection;
 use crate::{
-    Context, ContextBase, ContextSelectionSet, Name, OutputType, ServerError, ServerResult, Value,
+    Context, ContextBase, ContextSelectionSet, Error, Name, OutputType, ServerError, ServerResult,
+    Value,
 };
 
 /// Represents a GraphQL container object.
@@ -84,6 +85,23 @@ impl<T: ContainerType + ?Sized> ContainerType for Box<T> {
     }
 }
 
+#[async_trait::async_trait]
+impl<T: ContainerType, E: Into<Error> + Send + Sync + Clone> ContainerType for Result<T, E> {
+    async fn resolve_field(&self, ctx: &Context<'_>) -> ServerResult<Option<Value>> {
+        match self {
+            Ok(value) => T::resolve_field(value, ctx).await,
+            Err(err) => Err(ctx.set_error_path(err.clone().into().into_server_error(ctx.item.pos))),
+        }
+    }
+
+    async fn find_entity(&self, ctx: &Context<'_>, params: &Value) -> ServerResult<Option<Value>> {
+        match self {
+            Ok(value) => T::find_entity(value, ctx, params).await,
+            Err(err) => Err(ctx.set_error_path(err.clone().into().into_server_error(ctx.item.pos))),
+        }
+    }
+}
+
 /// Resolve an container by executing each of the fields concurrently.
 pub async fn resolve_container<'a, T: ContainerType + ?Sized>(
     ctx: &ContextSelectionSet<'a>,
